==> haskell-integer-logarithms-1.0.2.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.2.2
id: integer-logarithms-1.0.2.2-33gHWvkkotvKqvHmbqy5m0
key: integer-logarithms-1.0.2.2-33gHWvkkotvKqvHmbqy5m0
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Daniel Fischer
stability: Provisional
homepage: https://github.com/Bodigrim/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
abi: e0973d6eca2bc234a9a59aa682a163bc
exposed: True
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural
import-dirs: /usr/lib/ghc-8.6.4/site-local/integer-logarithms-1.0.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/integer-logarithms-1.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/integer-logarithms-1.0.2.2
hs-libraries: HSinteger-logarithms-1.0.2.2-33gHWvkkotvKqvHmbqy5m0
depends:
    array-0.5.3.0 base-4.12.0.0 ghc-prim-0.5.3 integer-gmp-1.0.2.0
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-logarithms-1.0.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.2
id: integer-logarithms-1.0.2-DIHxxI1QWYABsCCmZt9aKs
key: integer-logarithms-1.0.2-DIHxxI1QWYABsCCmZt9aKs
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
stability: Provisional
homepage: https://github.com/phadej/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
author: Daniel Fischer
exposed: True
indefinite: False
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural
abi: 9dd9daec2431fa3fcb9dd6e08ef04f6e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/integer-logarithms-1.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/integer-logarithms-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/integer-logarithms-1.0.2
hs-libraries: HSinteger-logarithms-1.0.2-DIHxxI1QWYABsCCmZt9aKs
depends:
    base-4.10.1.0 array-0.5.2.0 ghc-prim-0.5.1.1 integer-gmp-1.0.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             integer-gmp-1.0.1.0=9c3d9ccbdd7bdea277cdecf74e14db2b
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
